# aosp_easy

aosp_easy is a tool used for andoird source

## usage
create test app

```bash
aosp_easy app
```

create test service

```bash
aosp_easy service
```

## change log

1. add create app or service in aosp source code.